@@ -36,7 +36,6 @@
 #include "guiutility.h"
 #include "libsync/graphapi/spacesmanager.h"
 #include "openfilemanager.h"
-#include "quotainfo.h"
 #include "scheduling/syncscheduler.h"
 #include "settingsdialog.h"
 #include "theme.h"
@@ -69,13 +68,10 @@ AccountSettings::AccountSettings(AccountState *accountState, QWidget *parent)
 
     // as usual we do too many things in the ctr and we need to eval all the code paths to make sure they handle
     // the QPointer properly, but as a stopgap to catch null states asap before they trickle down into other areas:
-    Q_ASSERT(_accountState);
+    if (!_accountState || !_accountState->account())
+        return;
 
-
-    _model = new FolderStatusModel(this);
-
-    // see comments in this impl as it needs work
-    _model->setAccountState(_accountState);
+    _model = new FolderStatusModel(_accountState, this);
 
     auto weightedModel = new QSortFilterProxyModel(this);
     weightedModel->setSourceModel(_model);
@@ -84,19 +80,19 @@ AccountSettings::AccountSettings(AccountState *accountState, QWidget *parent)
 
     _sortModel = weightedModel;
 
-    ui->quickWidget->engine()->addImageProvider(QStringLiteral("space"), new Spaces::SpaceImageProvider(_accountState->account()));
+    ui->quickWidget->engine()->addImageProvider(QStringLiteral("space"), new Spaces::SpaceImageProvider(_accountState->account()->spacesManager()));
     ui->quickWidget->setOCContext(QUrl(QStringLiteral("qrc:/qt/qml/org/ownCloud/gui/qml/FolderDelegate.qml")), this);
 
     connect(FolderMan::instance(), &FolderMan::folderListChanged, _model, &FolderStatusModel::resetFolders);
 
     ui->connectionStatusLabel->clear();
 
-    connect(_accountState.data(), &AccountState::stateChanged, this, &AccountSettings::slotAccountStateChanged);
-    slotAccountStateChanged();
+    connect(_accountState, &AccountState::stateChanged, this, &AccountSettings::slotAccountStateChanged);
+    slotAccountStateChanged(_accountState->state());
 
     buildManageAccountMenu();
 
-    connect(_accountState.get(), &AccountState::isSettingUpChanged, this, &AccountSettings::accountSettingUpChanged);
+    connect(_accountState, &AccountState::isSettingUpChanged, this, &AccountSettings::accountSettingUpChanged);
 
     connect(ui->stackedWidget, &QStackedWidget::currentChanged, this,
         [this] { ui->manageAccountButton->setEnabled(ui->stackedWidget->currentWidget() == ui->quickWidget); });
@@ -147,7 +143,7 @@ void AccountSettings::slotCustomContextMenuRequested(Folder *folder)
     // am not able to easily determine what should happen in this handler if the state is null. For now we just assert
     // to make the "source" of the nullptr obvious before it trickles down into sub-areas and causes a crash that's harder
     // to id
-    Q_ASSERT(_accountState);
+    Q_ASSERT(_accountState && _accountState->account());
 
     // qpointer for async calls
     const auto isDeployed = folder->isDeployed();
@@ -258,7 +254,7 @@ void AccountSettings::slotCustomContextMenuRequested(Folder *folder)
 
 void AccountSettings::showSelectiveSyncDialog(Folder *folder)
 {
-    if (!_accountState) {
+    if (!_accountState || !_accountState->account()) {
         return;
     }
 
@@ -280,11 +276,11 @@ void AccountSettings::showSelectiveSyncDialog(Folder *folder)
 
 void AccountSettings::slotAddFolder()
 {
-    if (!_accountState) {
+    if (!_accountState || !_accountState->account()) {
         return;
     }
 
-    FolderWizard *folderWizard = new FolderWizard(_accountState, this);
+    FolderWizard *folderWizard = new FolderWizard(_accountState->account(), this);
     folderWizard->setAttribute(Qt::WA_DeleteOnClose);
 
     connect(folderWizard, &QDialog::accepted, this, &AccountSettings::slotFolderWizardAccepted);
@@ -527,14 +523,13 @@ void AccountSettings::buildManageAccountMenu()
 }
 
 // Refactoring todo: the signal sends the new account state, refactor this to use that param
-void AccountSettings::slotAccountStateChanged()
+void AccountSettings::slotAccountStateChanged(AccountState::State state)
 {
-    if (!_accountState) {
+    if (!_accountState || !_accountState->account()) {
         return;
     }
 
-    const AccountState::State state = _accountState->state();
-    const AccountPtr account = _accountState->account();
+    Account *account = _accountState->account();
     qCDebug(lcAccountSettings) << "Account state changed to" << state << "for account" << account;
 
     FolderMan *folderMan = FolderMan::instance();
@@ -551,13 +546,11 @@ void AccountSettings::slotAccountStateChanged()
             icon = StatusIcon::Warning;
         }
         showConnectionLabel(tr("Connected"), icon, errors);
-        if (_accountState->supportsSpaces()) {
-            connect(_accountState->account()->spacesManager(), &GraphApi::SpacesManager::updated, this, &AccountSettings::slotSpacesUpdated,
-                Qt::UniqueConnection);
-            // Refactoring todo: won't this get called every time the state changes to connected even if the spaces manager is already
-            // triggering the slot? ie duplicate call to slotSpacesUpdated?
-            slotSpacesUpdated();
-        }
+        connect(_accountState->account()->spacesManager(), &GraphApi::SpacesManager::updated, this, &AccountSettings::slotSpacesUpdated, Qt::UniqueConnection);
+        // Refactoring todo: won't this get called every time the state changes to connected even if the spaces manager is already
+        // triggering the slot? ie duplicate call to slotSpacesUpdated?
+        slotSpacesUpdated();
+
         break;
     }
     case AccountState::ServiceUnavailable:
@@ -596,8 +589,7 @@ void AccountSettings::slotAccountStateChanged()
 
 void AccountSettings::slotSpacesUpdated()
 {
-    if (!_accountState || !_accountState->supportsSpaces()) {
-        // oC10 does not support spaces, and there is no `SpacesManager` available.
+    if (!_accountState || !_accountState->account() || !_accountState->account()->spacesManager()) {
         return;
     }
 
@@ -700,21 +692,21 @@ void AccountSettings::addModalLegacyDialog(QWidget *widget, ModalWidgetSizePolic
     Q_ASSERT(widget->testAttribute(Qt::WA_DeleteOnClose));
 
     // Refactoring todo: eval this more completely
-    Q_ASSERT(_accountState);
+    Q_ASSERT(_accountState && _accountState->account());
 
     connect(widget, &QWidget::destroyed, this, [this, outerWidget] {
         outerWidget->deleteLater();
         if (!_goingDown) {
-            ocApp()->gui()->settingsDialog()->ceaseModality(_accountState->account().get());
+            ocApp()->gui()->settingsDialog()->ceaseModality(_accountState->account());
         }
     });
     widget->setVisible(true);
-    ocApp()->gui()->settingsDialog()->requestModality(_accountState->account().get());
+    ocApp()->gui()->settingsDialog()->requestModality(_accountState->account());
 }
 
 void AccountSettings::addModalAccountWidget(AccountModalWidget *widget)
 {
-    if (!_accountState) {
+    if (!_accountState || !_accountState->account()) {
         return;
     }
 
@@ -723,9 +715,9 @@ void AccountSettings::addModalAccountWidget(AccountModalWidget *widget)
 
     connect(widget, &AccountModalWidget::finished, this, [widget, this] {
         widget->deleteLater();
-        ocApp()->gui()->settingsDialog()->ceaseModality(_accountState->account().get());
+        ocApp()->gui()->settingsDialog()->ceaseModality(_accountState->account());
     });
-    ocApp()->gui()->settingsDialog()->requestModality(_accountState->account().get());
+    ocApp()->gui()->settingsDialog()->requestModality(_accountState->account());
 }
 
 uint AccountSettings::unsyncedSpaces() const
@@ -764,14 +756,4 @@ void AccountSettings::slotDeleteAccount()
     messageBox->open();
 }
 
-bool AccountSettings::event(QEvent *e)
-{
-    if (e->type() == QEvent::Hide || e->type() == QEvent::Show) {
-        if (_accountState && !_accountState->supportsSpaces()) {
-            _accountState->quotaInfo()->setActive(isVisible());
-        }
-    }
-    return QWidget::event(e);
-}
-
 } // namespace OCC
