@@ -16,12 +16,10 @@
 #include "application.h"
 #include "configfile.h"
 
-#include "credentials.h"
 #include "fetchserversettings.h"
 
 #include "libsync/creds/abstractcredentials.h"
 
-#include "quotainfo.h"
 #include "gui/settingsdialog.h"
 #include "gui/tlserrordialog.h"
 
@@ -50,7 +48,7 @@ namespace OCC {
 
 Q_LOGGING_CATEGORY(lcAccountState, "gui.account.state", QtInfoMsg)
 
-AccountState::AccountState(AccountPtr account)
+AccountState::AccountState(Account *account)
     : QObject()
     , _account(account)
     , _queueGuard(_account->jobQueue())
@@ -62,6 +60,8 @@ AccountState::AccountState(AccountPtr account)
 {
     qRegisterMetaType<AccountState *>("AccountState*");
 
+    Q_ASSERT(_account);
+
     connectAccount();
     connectNetworkInformation();
 
@@ -75,12 +75,11 @@ AccountState::AccountState(AccountPtr account)
     connect(timer, &QTimer::timeout, this, [this] { checkConnectivity(false); });
     timer->start();
 
-    connect(account->credentials(), &AbstractCredentials::requestLogout, this, [this] {
-        setState(State::SignedOut);
-    });
+    connect(_account->credentials(), &AbstractCredentials::requestLogout, this, [this] { setState(State::SignedOut); });
 
+    // todo: no we should not directly register the account, but let accountAdded signal trigger it
     if (FolderMan::instance()) {
-        FolderMan::instance()->socketApi()->registerAccount(account);
+        FolderMan::instance()->socketApi()->registerAccount(_account.get());
     }
 }
 
@@ -116,9 +115,9 @@ void AccountState::connectNetworkInformation()
     connect(NetworkInformation::instance(), &NetworkInformation::isBehindCaptivePortalChanged, this, &AccountState::onBehindCaptivePortalChanged);
 }
 
-std::unique_ptr<AccountState> AccountState::loadFromSettings(AccountPtr account, const QSettings &settings)
+AccountState *AccountState::loadFromSettings(Account *account, const QSettings &settings)
 {
-    auto accountState = std::unique_ptr<AccountState>(new AccountState(account));
+    auto accountState = new AccountState(account);
     const bool userExplicitlySignedOut = settings.value(userExplicitlySignedOutC(), false).toBool();
     if (userExplicitlySignedOut) {
         // see writeToSettings below
@@ -128,15 +127,6 @@ std::unique_ptr<AccountState> AccountState::loadFromSettings(AccountPtr account,
     return accountState;
 }
 
-std::unique_ptr<AccountState> AccountState::fromNewAccount(AccountPtr account)
-{
-    // todo: #22. In essence this function creates a unique pointer which in the caller is immediately added to the _accounts map
-    // as a QPointer. Meanwhile the parent is a shared pointer (the account) so who knows when this thing will ever get cleaned up?
-    // add to this that I rarely see anyone checking an account state to see if it's null. We need a consistent impl that reflects
-    // the ownership status of these elements, and make the lifetime concrete
-    return std::unique_ptr<AccountState>(new AccountState(account));
-}
-
 void AccountState::writeToSettings(QSettings &settings) const
 {
     // The SignedOut state is the only state where the client should *not* ask for credentials, nor
@@ -147,7 +137,7 @@ void AccountState::writeToSettings(QSettings &settings) const
     settings.setValue(userExplicitlySignedOutC(), _state == SignedOut);
 }
 
-AccountPtr AccountState::account() const
+Account *AccountState::account() const
 {
     return _account;
 }
@@ -169,6 +159,9 @@ AccountState::State AccountState::state() const
 
 void AccountState::setState(State state)
 {
+    if (!_account)
+        return;
+
     const State oldState = _state;
     if (_state != state) {
         qCInfo(lcAccountState) << "AccountState state change: " << _state << "->" << state;
@@ -201,13 +194,12 @@ void AccountState::setState(State state)
             // ensure the connection validator is done
             _queueGuard.unblock();
             // update capabilities and fetch relevant settings
-            _fetchCapabilitiesJob = new FetchServerSettingsJob(account(), this);
+            _fetchCapabilitiesJob = new FetchServerSettingsJob(_account, this);
             connect(_fetchCapabilitiesJob.get(), &FetchServerSettingsJob::finishedSignal, this, [oldState, this] {
                 // Lisa todo: I do not understand this logic at all - review it
                 if (oldState == Connected || _state == Connected) {
                     _fetchCapabilitiesJob.clear();
                     Q_EMIT isConnectedChanged();
-                    Q_EMIT supportsSpacesChanged();
                 }
             });
             _fetchCapabilitiesJob->start();
@@ -226,11 +218,14 @@ bool AccountState::isSignedOut() const
 
 void AccountState::signOutByUi()
 {
-    account()->credentials()->forgetSensitiveData();
-    account()->clearCookieJar();
+    if (!_account)
+        return;
+
+    _account->credentials()->forgetSensitiveData();
+    _account->clearCookieJar();
     setState(SignedOut);
     // persist that we are signed out
-    Q_EMIT account()->wantsAccountSaved(account().data());
+    Q_EMIT _account->wantsAccountSaved(_account);
 }
 
 void AccountState::freshConnectionAttempt()
@@ -242,11 +237,13 @@ void AccountState::freshConnectionAttempt()
 
 void AccountState::signIn()
 {
+    if (!_account)
+        return;
     if (_state == SignedOut) {
         _waitingForNewCredentials = false;
         setState(Disconnected);
         // persist that we are no longer signed out
-        Q_EMIT account()->wantsAccountSaved(account().data());
+        Q_EMIT account()->wantsAccountSaved(_account);
     }
 }
 
@@ -314,7 +311,7 @@ void AccountState::checkConnectivity(bool blockJobs)
 
     // =======  here we setup a new ConnectionValidator
 
-    _connectionValidator = new ConnectionValidator(_account, this);
+    _connectionValidator = new ConnectionValidator(_account.get(), this);
     connect(_connectionValidator, &ConnectionValidator::connectionResult, this, &AccountState::slotConnectionValidatorResult);
     connect(_connectionValidator, &ConnectionValidator::sslErrors, this,
         [blockJobs, this](const QList<QSslError> &errors) { handleSslConnectionErrors(errors, blockJobs); });
@@ -538,14 +535,14 @@ void AccountState::slotInvalidCredentials()
             account()->credentials()->invalidateToken();
         }
         // todo: evaluate if this is even needed (it seems to be working fine casting to HttpCredentials which would have failed to cast -> ie it's a
-        // noop), and if it is, fix the abstraction todo: needs update in AbstractCredentials
-        if (auto creds = qobject_cast<Credentials *>(account()->credentials())) {
-            qCInfo(lcAccountState) << "refreshing oauth";
-            if (creds->refreshAccessToken()) {
-                return;
-            }
-            qCInfo(lcAccountState) << "refreshing oauth failed";
-        }
+        // noop), and if it is, fix the abstraction as casting to the subclass is stinky
+        /* if (auto creds = qobject_cast<HttpCredentials *>(account()->credentials())) {
+             qCInfo(lcAccountState) << "refreshing oauth";
+             if (creds->refreshAccessToken()) {
+                 return;
+             }
+             qCInfo(lcAccountState) << "refreshing oauth failed";
+         }*/
         qCInfo(lcAccountState) << "asking user";
         account()->credentials()->askFromUser();
         setState(AskingCredentials);
@@ -566,32 +563,16 @@ void AccountState::slotCredentialsFetched()
 
 Account *AccountState::accountForQml() const
 {
-    return _account.data();
+    return _account;
 }
 
 std::unique_ptr<QSettings> AccountState::settings()
 {
     auto s = ConfigFile::settingsWithGroup(QStringLiteral("Accounts"));
-    s->beginGroup(_account->id());
+    s->beginGroup(_account->groupIndex());
     return s;
 }
 
-bool AccountState::supportsSpaces() const
-{
-    Q_ASSERT(_account->hasCapabilities() && _account->capabilities().spacesSupport().enabled);
-    return true;
-}
-
-QuotaInfo *AccountState::quotaInfo()
-{
-    // QuotaInfo should not be used with spaces
-    Q_ASSERT(!supportsSpaces());
-    if (!_quotaInfo) {
-        _quotaInfo = new QuotaInfo(this);
-    }
-    return _quotaInfo;
-}
-
 bool AccountState::isSettingUp() const
 {
     return _settingUp;
