@@ -134,9 +134,6 @@ private:
     /// Which virtual files setting the folder uses
     Vfs::Mode _virtualFilesMode = Vfs::Off;
 
-    /// Whether the vfs mode shall silently be updated if possible
-    bool _upgradeVfsMode = false;
-
     // oc10 and as cache for ocis
     QUrl _webDavUrl;
 
@@ -280,8 +277,6 @@ public:
 
     void setSyncState(SyncResult::Status state);
 
-    void setDirtyNetworkLimits();
-
     void reloadSyncOptions();
 
 
@@ -437,9 +432,9 @@ private Q_SLOTS:
 
     void slotLogPropagationStart();
 
-    /** Adjust sync result based on conflict data from IssuesWidget.
+    /** Adjust sync result based on conflict data from SyncErrorWidget.
      *
-     * This is pretty awkward, but IssuesWidget just keeps better track
+     * This is pretty awkward, but SyncErrorWidget just keeps better track
      * of conflicts across partial local discovery.
      */
     void slotFolderConflicts(Folder *folder, const QStringList &conflictPaths);
