@@ -17,8 +17,8 @@
 #include "account.h"
 #include "accountmanager.h"
 #include "accountstate.h"
+#include "accessmanager.h"
 #include "common/asserts.h"
-#include "common/depreaction.h"
 #include "configfile.h"
 #include "folder.h"
 #include "gui/networkinformation.h"
@@ -39,7 +39,6 @@
 #include <QMutableSetIterator>
 #include <QNetworkProxy>
 #include <QStringLiteral>
-#include <QtCore>
 
 using namespace std::chrono;
 using namespace std::chrono_literals;
@@ -65,9 +64,15 @@ void TrayOverallStatusResult::addResult(Folder *f)
         lastSyncDone = time;
     }
 
+    // use status of the folder
     auto status = f->syncPaused() || NetworkInformation::instance()->isBehindCaptivePortal() || NetworkInformation::instance()->isMetered()
         ? SyncResult::Paused
         : f->syncResult().status();
+    // in case the linked account is not connected -> we are offline
+    if (!f->accountState()->isConnected()) {
+        status = SyncResult::Offline;
+    }
+    // undefined state means we are in trouble
     if (status == SyncResult::Undefined) {
         status = SyncResult::Problem;
     }
@@ -165,12 +170,9 @@ std::optional<qsizetype> FolderMan::setupFoldersFromConfig()
     qCInfo(lcFolderMan) << "Setup folders from settings file";
 
     for (const auto &account : AccountManager::instance()->accounts()) {
-        // ignore the deprecation warning on account()->id() for now. It's basically a zero based index relative to
-        // the account instances. It looks fragile to me but Erik said "don't touch it!" I'm guessing it would
-        // require some migration step at least to switch from this id to the preferred uuid
-        const auto accountId = account->account()->id();
-        Q_ASSERT(!accountId.isEmpty());
-        if (!accountsWithSettings.contains(accountId)) {
+        const auto accountIndex = account->account()->groupIndex();
+        Q_ASSERT(!accountIndex.isEmpty());
+        if (!accountsWithSettings.contains(accountIndex)) {
             qCWarning(lcFolderMan) << "Account id from account manager is missing from Config";
             continue;
         }
@@ -194,7 +196,7 @@ std::optional<qsizetype> FolderMan::setupFoldersFromConfig()
 
 bool FolderMan::addFoldersFromConfigByAccount(QSettings &settings, AccountState *account)
 {
-    settings.beginGroup(QStringLiteral("%1/Folders").arg(account->account()->id()));
+    settings.beginGroup(QStringLiteral("%1/Folders").arg(account->account()->groupIndex()));
 
     const auto &childGroups = settings.childGroups();
     for (const auto &folderAlias : childGroups) {
@@ -224,30 +226,14 @@ bool FolderMan::addFoldersFromConfigByAccount(QSettings &settings, AccountState
 
 void FolderMan::setUpInitialSyncFolders(AccountState *accountState, bool useVfs)
 {
-    if (accountState->supportsSpaces()) {
+    if (accountState && accountState->account() && accountState->account()->spacesManager()) {
         QObject::connect(accountState->account()->spacesManager(), &GraphApi::SpacesManager::ready, this,
             [this, accountState, useVfs] { loadSpacesWhenReady(accountState, useVfs); });
         // this is questionable - basically if the spaces aren't ready requesting "checkReady" triggers "getting them ready" - there is no way to directly
-        // ask "are you ready?" - in all cases you have to call this function to get the ready signal which is handled here
+        // ask "are you ready?" - in all cases you have to call this function to get the ready signal which is handled above
         // todo: #10
         accountState->account()->spacesManager()->checkReady();
-    } else {
-        // todo: #20
-        setSyncEnabled(false);
-        auto def = FolderDefinition::createNewFolderDefinition(accountState->account()->davUrl(), {}, {});
-        def.setLocalPath(accountState->account()->defaultSyncRoot());
-        def.setTargetPath(Theme::instance()->defaultServerFolder());
-        Folder *folder = addFolderFromScratch(accountState, std::move(def), useVfs);
-        if (folder) {
-            saveFolder(folder);
-            _scheduler->enqueueFolder(folder, SyncScheduler::Priority::High);
-        }
-        setSyncEnabled(true);
     }
-
-
-    // todo: #11
-    // accountState->checkConnectivity();
 }
 
 void FolderMan::loadSpacesWhenReady(AccountState *accountState, bool useVfs)
@@ -270,7 +256,7 @@ void FolderMan::loadSpacesWhenReady(AccountState *accountState, bool useVfs)
         settings.beginGroup("Accounts");
 
         // prepare the root - reality check this as I think the user can change this from default?
-        const QString localDir(spacesMgr->account()->defaultSyncRoot());
+        const QString localDir(accountState->account()->defaultSyncRoot());
         if (!prepareFolder(localDir)) {
             return;
         }
@@ -283,7 +269,7 @@ void FolderMan::loadSpacesWhenReady(AccountState *accountState, bool useVfs)
 
             folderDef.setPriority(space->priority());
 
-            QString localPath = findGoodPathForNewSyncFolder(localDir, folderDef.displayName(), NewFolderType::SpacesFolder, spacesMgr->account()->uuid());
+            QString localPath = findGoodPathForNewSyncFolder(localDir, folderDef.displayName(), NewFolderType::SpacesFolder, accountState->account()->uuid());
             folderDef.setLocalPath(localPath);
             folderDef.setTargetPath({});
 
@@ -437,7 +423,7 @@ void FolderMan::slotRemoveFoldersForAccount(AccountState *accountState)
         return;
     }
     QSettings settings = ConfigFile::makeQSettings();
-    QString accountGroup = QStringLiteral("Accounts/%1").arg(accountState->account()->id());
+    QString accountGroup = QStringLiteral("Accounts/%1").arg(accountState->account()->groupIndex());
     settings.beginGroup(accountGroup);
     QList<Folder *> foldersToRemove;
     // reserve a magic number
@@ -471,7 +457,7 @@ void FolderMan::removeFolderSettings(Folder *folder, QSettings &settings)
 void FolderMan::removeFolderSettings(Folder *folder)
 {
     QSettings settings = ConfigFile::makeQSettings();
-    QString accountGroup = QStringLiteral("Accounts/%1").arg(folder->accountState()->account()->id());
+    QString accountGroup = QStringLiteral("Accounts/%1").arg(folder->accountState()->account()->groupIndex());
     settings.beginGroup(accountGroup);
     removeFolderSettings(folder, settings);
 }
@@ -484,26 +470,13 @@ void FolderMan::slotServerVersionChanged(Account *account)
                                << "pausing all folders on the account";
 
         for (auto &f : std::as_const(_folders)) {
-            if (f->accountState()->account().data() == account) {
+            if (f->accountState()->account() == account) {
                 f->setSyncPaused(true);
             }
         }
     }
 }
 
-bool FolderMan::isAnySyncRunning() const
-{
-    if (_scheduler->hasCurrentRunningSyncRunning()) {
-        return true;
-    }
-
-    for (auto f : _folders) {
-        if (f->isSyncRunning())
-            return true;
-    }
-    return false;
-}
-
 void FolderMan::slotFolderSyncStarted()
 {
     auto f = qobject_cast<Folder *>(sender());
@@ -626,7 +599,7 @@ void FolderMan::saveFolder(Folder *folder, QSettings &settings)
     Q_ASSERT(settings.group() == QStringLiteral("Accounts"));
 
     auto strId = QString::fromUtf8(folder->definition().id());
-    QString targetGroup = QStringLiteral("%1/Folders/%2").arg(folder->accountState()->account()->id(), strId);
+    QString targetGroup = QStringLiteral("%1/Folders/%2").arg(folder->accountState()->account()->groupIndex(), strId);
     settings.beginGroup(targetGroup);
     FolderDefinition::save(settings, folder->definition());
     settings.endGroup();
@@ -660,31 +633,6 @@ Folder *FolderMan::folderForPath(const QString &path, QString *relativePath)
     return nullptr;
 }
 
-QStringList FolderMan::findFileInLocalFolders(const QString &relPath, const AccountPtr acc)
-{
-    QStringList re;
-
-    // We'll be comparing against Folder::remotePath which always starts with /
-    QString serverPath = relPath;
-    if (!serverPath.startsWith(QLatin1Char('/')))
-        serverPath.prepend(QLatin1Char('/'));
-
-    for (auto *folder : std::as_const(_folders)) {
-        if (acc != nullptr && folder->accountState()->account() != acc) {
-            continue;
-        }
-        if (!serverPath.startsWith(folder->remotePath()))
-            continue;
-
-        QString path = folder->cleanPath() + QLatin1Char('/');
-        path += serverPath.mid(folder->remotePathTrailingSlash().length());
-        if (QFile::exists(path)) {
-            re.append(path);
-        }
-    }
-    return re;
-}
-
 void FolderMan::removeFolderSync(Folder *f)
 {
     if (!OC_ENSURE(f)) {
@@ -748,51 +696,6 @@ void FolderMan::setDirtyProxy()
     }
 }
 
-void FolderMan::setDirtyNetworkLimits()
-{
-    for (auto *f : std::as_const(_folders)) {
-        // set only in busy folders. Otherwise they read the config anyway.
-        if (f && f->isSyncRunning()) {
-            f->setDirtyNetworkLimits();
-        }
-    }
-}
-
-TrayOverallStatusResult FolderMan::trayOverallStatus(const QVector<Folder *> &folders)
-{
-    TrayOverallStatusResult result;
-
-    // if one of them has an error -> show error
-    // if one is paused, but others ok, show ok
-    //
-    for (auto *folder : folders) {
-        result.addResult(folder);
-    }
-    return result;
-}
-
-QString FolderMan::trayTooltipStatusString(const SyncResult &result, bool paused)
-{
-    QString folderMessage;
-    switch (result.status()) {
-    case SyncResult::Success:
-        [[fallthrough]];
-    case SyncResult::Problem:
-        if (result.hasUnresolvedConflicts()) {
-            folderMessage = tr("Sync was successful, unresolved conflicts.");
-            break;
-        }
-        [[fallthrough]];
-    default:
-        return Utility::enumToDisplayName(result.status());
-    }
-    if (paused) {
-        // sync is disabled.
-        folderMessage = tr("%1 (Sync is paused)").arg(folderMessage);
-    }
-    return folderMessage;
-}
-
 // QFileInfo::canonicalPath returns an empty string if the file does not exist.
 // This function also works with files that does not exist and resolve the symlinks in the
 // parent directories.
