@@ -17,7 +17,6 @@
 #include "accountstate.h"
 #include "folderman.h"
 #include "gui/networkinformation.h"
-#include "gui/quotainfo.h"
 #include "theme.h"
 
 #include "libsync/graphapi/space.h"
@@ -26,8 +25,8 @@
 #include <QApplication>
 #include <QFileIconProvider>
 #include <QRandomGenerator>
+#include <QWidget>
 
-#include <set>
 
 using namespace std::chrono_literals;
 
@@ -175,65 +174,31 @@ namespace {
     }
 }
 
-
-FolderStatusModel::FolderStatusModel(QObject *parent)
+FolderStatusModel::FolderStatusModel(AccountState *accountState, QObject *parent)
     : QAbstractListModel(parent)
-    , _accountState(nullptr)
+    , _accountState(accountState)
 {
-}
+    connect(FolderMan::instance(), &FolderMan::folderSyncStateChange, this, &FolderStatusModel::slotFolderSyncStateChange);
 
-FolderStatusModel::~FolderStatusModel() { }
-
-void FolderStatusModel::setAccountState(AccountState *accountState)
-{
-    // Refactoring todo: what is the logic here? I especially don't understand why we are expecting current _accountState to
-    // be nullptr (via assert) when this is called.
-    // if this ptr should only be set once:
-    //      public setter must be removed
-    //      the ptr should be passed to the FolderStatusModel ctr as a one shot setting.
-    //      if useful, split the setup routine(s) into a "configure" method that can be called after the ctr.
-    //      I am also in favor of independent "connect" and "disconnect" functions to keep all that logic in one place
-    //      instead of spread out all over the place. call it after construction.
-    beginResetModel();
-    _folders.clear();
-    // at least test to see if the "new" account state is legit before we go through all the setup
-    if (accountState && _accountState != accountState) {
-        Q_ASSERT(!_accountState);
-        _accountState = accountState;
-
-        connect(FolderMan::instance(), &FolderMan::folderSyncStateChange, this, &FolderStatusModel::slotFolderSyncStateChange);
-
-        if (accountState->supportsSpaces()) {
-            connect(accountState->account()->spacesManager(), &GraphApi::SpacesManager::updated, this,
-                [this] { Q_EMIT dataChanged(index(0, 0), index(rowCount() - 1, 0)); });
-            connect(accountState->account()->spacesManager(), &GraphApi::SpacesManager::spaceChanged, this, [this](auto *space) {
-                for (int i = 0; i < rowCount(); ++i) {
-                    if (_folders[i]->_folder->space() == space) {
-                        Q_EMIT dataChanged(index(i, 0), index(i, 0));
-                        break;
-                    }
+    if (_accountState && _accountState->account() && _accountState->account()->spacesManager()) {
+        // todo: we should not update the whole folder model any time the spaces are updated, implement spaceAdded and removed to deal with that incrementally
+        connect(_accountState->account()->spacesManager(), &GraphApi::SpacesManager::updated, this,
+            [this] { Q_EMIT dataChanged(index(0, 0), index(rowCount() - 1, 0)); });
+        connect(_accountState->account()->spacesManager(), &GraphApi::SpacesManager::spaceChanged, this, [this](auto *space) {
+            for (int i = 0; i < rowCount(); ++i) {
+                if (_folders[i]->_folder->space() == space) {
+                    Q_EMIT dataChanged(index(i, 0), index(i, 0));
+                    break;
                 }
-            });
-        }
-    }
-    for (const auto &f : FolderMan::instance()->folders()) {
-        if (!accountState)
-            break;
-        if (f->accountState() != accountState)
-            continue;
-
-        _folders.push_back(std::make_unique<SubFolderInfo>(f));
-
-        connect(ProgressDispatcher::instance(), &ProgressDispatcher::progressInfo, this, [f, this](Folder *folder, const ProgressInfo &progress) {
-            if (folder == f) {
-                slotSetProgress(progress, f);
             }
         });
     }
 
-    endResetModel();
+    resetFolders();
 }
 
+FolderStatusModel::~FolderStatusModel() { }
+
 QVariant FolderStatusModel::data(const QModelIndex &index, int role) const
 {
     if (_accountState == nullptr)
@@ -292,18 +257,15 @@ QVariant FolderStatusModel::data(const QModelIndex &index, int role) const
     case Roles::Quota: {
         qint64 used{};
         qint64 total{};
-        if (_accountState->supportsSpaces()) {
-            if (auto *space = f->space()) {
-                const auto quota = space->drive().getQuota();
-                if (quota.isValid()) {
-                    used = quota.getUsed();
-                    total = quota.getTotal();
-                }
+
+        if (auto *space = f->space()) {
+            const auto quota = space->drive().getQuota();
+            if (quota.isValid()) {
+                used = quota.getUsed();
+                total = quota.getTotal();
             }
-        } else {
-            used = f->accountState()->quotaInfo()->lastQuotaUsedBytes();
-            total = f->accountState()->quotaInfo()->lastQuotaTotalBytes();
         }
+
         if (total <= 0) {
             return {};
         }
@@ -356,7 +318,7 @@ void FolderStatusModel::slotUpdateFolderState(Folder *folder)
 {
     if (!folder)
         return;
-    for (int i = 0; i < _folders.size(); ++i) {
+    for (size_t i = 0; i < _folders.size(); ++i) {
         if (_folders.at(i)->_folder == folder) {
             Q_EMIT dataChanged(index(i, 0), index(i, 0));
         }
@@ -448,10 +410,30 @@ void FolderStatusModel::slotFolderSyncStateChange(Folder *f)
 
 void FolderStatusModel::resetFolders()
 {
-    if (_accountState == nullptr)
+    beginResetModel();
+    _folders.clear();
+
+    if (!_accountState) {
+        endResetModel();
         return;
-    // what does this even do? see the impl
-    setAccountState(_accountState);
+    }
+
+    // todo: there is already a plan to organize folders in the folderman by account using a lookup on the uuid. this kind of filtering in the dependent is not
+    // ok. also the folder should not have an accessor for the account state or any other "powerful" object.
+    for (const auto &f : FolderMan::instance()->folders()) {
+        if (f->accountState() != _accountState)
+            continue;
+
+        _folders.push_back(std::make_unique<SubFolderInfo>(f));
+
+        connect(ProgressDispatcher::instance(), &ProgressDispatcher::progressInfo, this, [f, this](Folder *folder, const ProgressInfo &progress) {
+            if (folder == f) {
+                slotSetProgress(progress, f);
+            }
+        });
+    }
+
+    endResetModel();
 }
 
 } // namespace OCC
