@@ -21,15 +21,14 @@
 #include "gui/commonstrings.h"
 
 #include "accountmanager.h"
+#include "accountstate.h"
 #include "common/asserts.h"
-#include "common/depreaction.h"
 #include "common/syncjournalfilerecord.h"
 #include "common/version.h"
 #include "filesystem.h"
 #include "folder.h"
 #include "folderman.h"
 #include "guiutility.h"
-#include "sharemanager.h"
 #include "syncengine.h"
 #include "syncfileitem.h"
 #include "theme.h"
@@ -101,7 +100,6 @@ static QString buildMessage(const QString &verb, const QString &path, const QStr
 namespace OCC {
 
 Q_LOGGING_CATEGORY(lcSocketApi, "gui.socketapi", QtInfoMsg)
-Q_LOGGING_CATEGORY(lcPublicLink, "gui.socketapi.publiclink", QtInfoMsg)
 
 void SocketListener::sendMessage(const QString &message, bool doWait) const
 {
@@ -139,7 +137,8 @@ SocketApi::SocketApi(QObject *parent)
     SocketApiServer::removeServer(_socketPath);
 
     // Create the socket path:
-    if (!Utility::isMac()) {
+    if (!Utility::isMac() && !Utility::isWindows()) {
+        // Not on Windows: a named pipe doesn't need a directory in the filesystem
         // Not on macOS: there the directory is there, and created for us by the sandboxing
         // environment, because we belong to an App Group.
         QFileInfo info(_socketPath);
@@ -155,11 +154,7 @@ SocketApi::SocketApi(QObject *parent)
     // Wire up the server instance to us, so we can accept new connections:
     connect(&_localServer, &SocketApiServer::newConnection, this, &SocketApi::slotNewConnection);
 
-    connect(AccountManager::instance(), &AccountManager::accountRemoved, this, [this](const auto &accountState) {
-        if (_registeredAccounts.contains(accountState->account())) {
-            unregisterAccount(accountState->account());
-        }
-    });
+    connect(AccountManager::instance(), &AccountManager::accountRemoved, this, &SocketApi::unregisterAccount);
 }
 
 SocketApi::~SocketApi()
@@ -209,7 +204,7 @@ void SocketApi::slotNewConnection()
     auto listener = QSharedPointer<SocketListener>::create(socket);
     _listeners.insert(socket, listener);
     for (const auto &a : std::as_const(_registeredAccounts)) {
-        if (a->hasDefaultSyncRoot()) {
+        if (a && !a->defaultSyncRoot().isEmpty()) {
             broadcastMessage(buildRegisterPathMessage(Utility::stripTrailingSlash(a->defaultSyncRoot())));
         }
     }
@@ -319,29 +314,31 @@ void SocketApi::slotReadSocket()
 }
 
 
-void SocketApi::registerAccount(const AccountPtr &a)
+void SocketApi::registerAccount(Account *a)
 {
     // Make sure not to register twice to each connected client
-    if (_registeredAccounts.contains(a)) {
+    if (!a || _registeredAccounts.contains(a->uuid())) {
         return;
     }
 
-    if (a->hasDefaultSyncRoot()) {
+    _registeredAccounts.insert(a->uuid(), a);
+
+    if (!a->defaultSyncRoot().isEmpty()) {
         broadcastMessage(buildRegisterPathMessage(Utility::stripTrailingSlash(a->defaultSyncRoot())));
     }
-    _registeredAccounts.insert(a);
 }
 
-void SocketApi::unregisterAccount(const AccountPtr &a)
+void SocketApi::unregisterAccount(AccountState *state)
 {
-    if (!_registeredAccounts.contains(a)) {
+    if (!state || !state->account())
         return;
-    }
 
-    if (a->hasDefaultSyncRoot()) {
+    Account *a = state->account();
+
+    if (!a->defaultSyncRoot().isEmpty()) {
         broadcastMessage(buildMessage(unregisterPathMessageC(), Utility::stripTrailingSlash(a->defaultSyncRoot())));
     }
-    _registeredAccounts.remove(a);
+    _registeredAccounts.remove(a->uuid());
 }
 
 void SocketApi::slotRegisterPath(Folder *folder)
@@ -410,47 +407,6 @@ void SocketApi::broadcastMessage(const QString &msg, bool doWait)
     }
 }
 
-void SocketApi::processShareRequest(const QString &localFile, SocketListener *listener, ShareDialogStartPage startPage)
-{
-    auto theme = Theme::instance();
-
-    auto fileData = FileData::get(localFile);
-    auto shareFolder = fileData.folder;
-    if (!shareFolder) {
-        const QString message = QLatin1String("SHARE:NOP:") + QDir::toNativeSeparators(localFile);
-        // files that are not within a sync folder are not synced.
-        listener->sendMessage(message);
-    } else if (!shareFolder->accountState()->isConnected()) {
-        const QString message = QLatin1String("SHARE:NOTCONNECTED:") + QDir::toNativeSeparators(localFile);
-        // if the folder isn't connected, don't open the share dialog
-        listener->sendMessage(message);
-    } else if (!theme->linkSharing() && !theme->userGroupSharing()) {
-        const QString message = QLatin1String("SHARE:NOP:") + QDir::toNativeSeparators(localFile);
-        listener->sendMessage(message);
-    } else {
-        // If the file doesn't have a journal record, it might not be uploaded yet
-        if (!fileData.journalRecord().isValid()) {
-            const QString message = QLatin1String("SHARE:NOTSYNCED:") + QDir::toNativeSeparators(localFile);
-            listener->sendMessage(message);
-            return;
-        }
-
-        auto &remotePath = fileData.serverRelativePath;
-
-        // Can't share root folder
-        if (remotePath == QLatin1String("/")) {
-            const QString message = QLatin1String("SHARE:CANNOTSHAREROOT:") + QDir::toNativeSeparators(localFile);
-            listener->sendMessage(message);
-            return;
-        }
-
-        const QString message = QLatin1String("SHARE:OK:") + QDir::toNativeSeparators(localFile);
-        listener->sendMessage(message);
-
-        Q_EMIT shareCommandReceived(remotePath, fileData.localPath, startPage);
-    }
-}
-
 void SocketApi::broadcastStatusPushMessage(const QString &systemPath, SyncFileStatus fileStatus)
 {
     QString msg = buildMessage(QStringLiteral("STATUS"), systemPath, fileStatus.toSocketAPIString());
@@ -490,12 +446,42 @@ void SocketApi::command_RETRIEVE_FILE_STATUS(const QString &argument, SocketList
 
 void SocketApi::command_SHARE(const QString &localFile, SocketListener *listener)
 {
-    processShareRequest(localFile, listener, ShareDialogStartPage::UsersAndGroups);
-}
+    auto fileData = FileData::get(localFile);
+    auto shareFolder = fileData.folder;
+    if (!shareFolder) {
+        const QString message = QLatin1String("SHARE:NOP:") + QDir::toNativeSeparators(localFile);
+        // files that are not within a sync folder are not synced.
+        listener->sendMessage(message);
+    } else if (!shareFolder->accountState()->isConnected()) {
+        const QString message = QLatin1String("SHARE:NOTCONNECTED:") + QDir::toNativeSeparators(localFile);
+        // if the folder isn't connected, don't open the share dialog
+        listener->sendMessage(message);
+    } else if (!shareFolder->accountState()->account()->capabilities().shareAPI()
+        || !shareFolder->accountState()->account()->capabilities().sharePublicLink()) {
+        const QString message = QLatin1String("SHARE:NOP:") + QDir::toNativeSeparators(localFile);
+        listener->sendMessage(message);
+    } else {
+        // If the file doesn't have a journal record, it might not be uploaded yet
+        if (!fileData.journalRecord().isValid()) {
+            const QString message = QLatin1String("SHARE:NOTSYNCED:") + QDir::toNativeSeparators(localFile);
+            listener->sendMessage(message);
+            return;
+        }
 
-void SocketApi::command_MANAGE_PUBLIC_LINKS(const QString &localFile, SocketListener *listener)
-{
-    processShareRequest(localFile, listener, ShareDialogStartPage::PublicLinks);
+        auto &remotePath = fileData.serverRelativePath;
+
+        // Can't share root folder
+        if (remotePath == QLatin1String("/")) {
+            const QString message = QLatin1String("SHARE:CANNOTSHAREROOT:") + QDir::toNativeSeparators(localFile);
+            listener->sendMessage(message);
+            return;
+        }
+
+        const QString message = QLatin1String("SHARE:OK:") + QDir::toNativeSeparators(localFile);
+        listener->sendMessage(message);
+
+        Q_EMIT shareCommandReceived(remotePath, fileData.localPath);
+    }
 }
 
 void SocketApi::command_VERSION(const QString &, SocketListener *listener)
@@ -505,116 +491,7 @@ void SocketApi::command_VERSION(const QString &, SocketListener *listener)
 
 void SocketApi::command_SHARE_MENU_TITLE(const QString &, SocketListener *listener)
 {
-    listener->sendMessage(QLatin1String("SHARE_MENU_TITLE:") + tr("Share with %1", "parameter is ownCloud").arg(Theme::instance()->appNameGUI()));
-}
-
-class GetOrCreatePublicLinkShare : public QObject
-{
-    Q_OBJECT
-public:
-    GetOrCreatePublicLinkShare(const AccountPtr &account,
-        const QString &serverPath, QObject *parent)
-        : QObject(parent)
-        , _account(account)
-        , _shareManager(account)
-        , _serverPath(serverPath)
-    {
-        connect(&_shareManager, &ShareManager::sharesFetched,
-            this, &GetOrCreatePublicLinkShare::sharesFetched);
-        connect(&_shareManager, &ShareManager::linkShareCreated,
-            this, &GetOrCreatePublicLinkShare::linkShareCreated);
-        connect(&_shareManager, &ShareManager::linkShareCreationForbidden,
-            this, &GetOrCreatePublicLinkShare::linkShareCreationForbidden);
-        connect(&_shareManager, &ShareManager::serverError,
-            this, &GetOrCreatePublicLinkShare::serverError);
-    }
-
-    void run()
-    {
-        qCDebug(lcPublicLink) << "Fetching shares";
-        _shareManager.fetchShares(_serverPath);
-    }
-
-private Q_SLOTS:
-    void sharesFetched(const QList<QSharedPointer<Share>> &shares)
-    {
-        auto shareName = SocketApi::tr("Context menu share");
-
-        // If shares will expire, create a new one every day.
-        QDate expireDate;
-        if (_account->capabilities().sharePublicLinkDefaultExpire()) {
-            shareName = SocketApi::tr("Context menu share %1").arg(QDate::currentDate().toString(Qt::ISODate));
-            expireDate = QDate::currentDate().addDays(
-                _account->capabilities().sharePublicLinkDefaultExpireDateDays());
-        }
-
-        // If there already is a context menu share, reuse it
-        for (const auto &share : shares) {
-            const auto linkShare = qSharedPointerDynamicCast<LinkShare>(share);
-            if (!linkShare)
-                continue;
-
-            if (linkShare->getName() == shareName) {
-                qCDebug(lcPublicLink) << "Found existing share, reusing";
-                return success(linkShare->getLink().toString());
-            }
-        }
-
-        // otherwise create a new one
-        qCDebug(lcPublicLink) << "Creating new share";
-        QString noPassword;
-        _shareManager.createLinkShare(_serverPath, shareName, noPassword, expireDate);
-    }
-
-    void linkShareCreated(const QSharedPointer<LinkShare> &share)
-    {
-        qCDebug(lcPublicLink) << "New share created";
-        success(share->getLink().toString());
-    }
-
-    void linkShareCreationForbidden(const QString &message)
-    {
-        qCInfo(lcPublicLink) << "Could not create link share:" << message;
-        Q_EMIT error(message);
-        deleteLater();
-    }
-
-    void serverError(int code, const QString &message)
-    {
-        qCWarning(lcPublicLink) << "Share fetch/create error" << code << message;
-        Q_EMIT error(message);
-        deleteLater();
-    }
-
-Q_SIGNALS:
-    void done(const QString &link);
-    void error(const QString &message);
-
-private:
-    void success(const QString &link)
-    {
-        Q_EMIT done(link);
-        deleteLater();
-    }
-
-    AccountPtr _account;
-    ShareManager _shareManager;
-    QString _serverPath;
-};
-
-void SocketApi::command_COPY_PUBLIC_LINK(const QString &localFile, SocketListener *)
-{
-    auto fileData = FileData::get(localFile);
-    if (!fileData.folder)
-        return;
-
-    AccountPtr account = fileData.folder->accountState()->account();
-    auto job = new GetOrCreatePublicLinkShare(account, fileData.serverRelativePath, this);
-    connect(job, &GetOrCreatePublicLinkShare::done, this,
-        [](const QString &url) { copyUrlToClipboard(QUrl(url)); });
-    connect(job, &GetOrCreatePublicLinkShare::error, this,
-        [=]() { Q_EMIT shareCommandReceived(fileData.serverRelativePath, fileData.localPath, ShareDialogStartPage::PublicLinks); });
-    job->run();
+    listener->sendMessage(QLatin1String("SHARE_MENU_TITLE:") + tr("Share with %1", "parameter is the application name").arg(Theme::instance()->appNameGUI()));
 }
 
 // Fetches the private link url asynchronously and then calls the target slot
@@ -632,12 +509,7 @@ void SocketApi::fetchPrivateLinkUrlHelper(const QString &localFile, const std::f
             return;
     }
 
-    fetchPrivateLinkUrl(
-        fileData.folder->accountState()->account(),
-        fileData.folder->webDavUrl(),
-        fileData.serverRelativePath,
-        this,
-        targetFun);
+    fetchPrivateLinkUrl(fileData.folder->accountState()->account(), fileData.folder->webDavUrl(), fileData.serverRelativePath, this, targetFun);
 }
 
 void SocketApi::command_COPY_PRIVATE_LINK(const QString &localFile, SocketListener *)
@@ -796,18 +668,6 @@ Q_INVOKABLE void OCC::SocketApi::command_OPEN_APP_LINK(const QString &localFile,
     }
 }
 
-void SocketApi::command_V2_LIST_ACCOUNTS(const QSharedPointer<SocketApiJobV2> &job) const
-{
-    QJsonArray out;
-    for (auto acc : AccountManager::instance()->accounts()) {
-        OC_DISABLE_DEPRECATED_WARNING; // allow use of id
-        out << QJsonObject({{QStringLiteral("name"), acc->account()->displayNameWithHost()}, {QStringLiteral("id"), acc->account()->id()},
-            {QStringLiteral("uuid"), acc->account()->uuid().toString(QUuid::WithoutBraces)}});
-        OC_ENABLE_DEPRECATED_WARNING
-    }
-    job->success({ { QStringLiteral("accounts"), out } });
-}
-
 void SocketApi::command_V2_GET_CLIENT_ICON(const QSharedPointer<SocketApiJobV2> &job) const
 {
     OC_ASSERT(job);
@@ -871,7 +731,6 @@ void SocketApi::command_GET_STRINGS(const QString &argument, SocketListener *lis
         { QStringLiteral("SHARE_MENU_TITLE"), tr("Share...") },
         { QStringLiteral("CONTEXT_MENU_TITLE"), Theme::instance()->appNameGUI() },
         { QStringLiteral("COPY_PRIVATE_LINK_MENU_TITLE"), tr("Copy private link to clipboard") },
-        { QStringLiteral("EMAIL_PRIVATE_LINK_MENU_TITLE"), tr("Send private link by email...") },
     } };
     listener->sendMessage(QStringLiteral("GET_STRINGS:BEGIN"));
     for (auto key_value : strings) {
@@ -889,34 +748,16 @@ void SocketApi::sendSharingContextMenuOptions(const FileData &fileData, SocketLi
     auto flagString = isOnTheServer ? QStringLiteral("::") : QStringLiteral(":d:");
 
     auto capabilities = fileData.folder->accountState()->account()->capabilities();
-    auto theme = Theme::instance();
-    if (!capabilities.shareAPI() || !(theme->userGroupSharing() || (theme->linkSharing() && capabilities.sharePublicLink())))
+    if (!capabilities.shareAPI() || !capabilities.sharePublicLink())
         return;
 
     // If sharing is globally disabled, do not show any sharing entries.
     // If there is no permission to share for this file, add a disabled entry saying so
     if (isOnTheServer && !record._remotePerm.isNull() && !record._remotePerm.hasPermission(RemotePermissions::CanReshare)) {
-        listener->sendMessage(QStringLiteral("MENU_ITEM:DISABLED:d:") + (!record.isDirectory() ? tr("Resharing this file is not allowed") : tr("Resharing this folder is not allowed")));
+        listener->sendMessage(QStringLiteral("MENU_ITEM:DISABLED:d:")
+            + (record.isDirectory() ? tr("Resharing this folder is not allowed") : tr("Resharing this file is not allowed")));
     } else {
         listener->sendMessage(QStringLiteral("MENU_ITEM:SHARE") + flagString + tr("Share..."));
-
-        // Do we have public links?
-        bool publicLinksEnabled = theme->linkSharing() && capabilities.sharePublicLink();
-
-        // It is possible to create a public link without user choices?
-        bool canCreateDefaultPublicLink = publicLinksEnabled
-            && !capabilities.sharePublicLinkEnforcePasswordForReadOnly();
-
-        if (canCreateDefaultPublicLink) {
-            if (fileData.folder->accountState()->supportsSpaces()) {
-                // TODO: See https://github.com/owncloud/client/issues/10845 : oCIS is getting a new sharing API, waiting for that before implementing a
-                // temporary solution.
-            } else {
-                listener->sendMessage(QStringLiteral("MENU_ITEM:COPY_PUBLIC_LINK") + flagString + tr("Create and copy public link to clipboard"));
-            }
-        } else if (publicLinksEnabled) {
-            listener->sendMessage(QStringLiteral("MENU_ITEM:MANAGE_PUBLIC_LINKS") + flagString + tr("Manage public links"));
-        }
     }
 
     if (capabilities.privateLinkPropertyAvailable()) {
