@@ -22,17 +22,12 @@ namespace OCC {
 
 Q_LOGGING_CATEGORY(lcCredentials, "sync.credentials", QtInfoMsg)
 
-AbstractCredentials::AbstractCredentials(QObject *parent)
+AbstractCredentials::AbstractCredentials(Account *account, QObject *parent)
     : QObject(parent)
-    , _account(nullptr)
+    , _account(account)
     , _wasEverFetched(false)
 {
 }
 
-void AbstractCredentials::setAccount(Account *account)
-{
-    OC_ENFORCE_X(!_account, "should only setAccount once");
-    _account = account;
-}
 
 } // namespace OCC
