@@ -14,7 +14,6 @@
 
 #include "discovery.h"
 #include "csync.h"
-#include "owncloudpropagator.h"
 #include "syncfileitem.h"
 
 #include "csync/csync_exclude.h"
@@ -25,7 +24,6 @@
 
 #include "libsync/theme.h"
 
-#include <algorithm>
 
 #include <QFile>
 #include <QFileInfo>
@@ -41,6 +39,8 @@ void ProcessDirectoryJob::start()
 
     if (_queryServer == NormalQuery) {
         _serverJob = startAsyncServerQuery();
+        if (!_serverJob)
+            return;
     } else {
         _serverQueryDone = true;
     }
@@ -550,6 +550,10 @@ void ProcessDirectoryJob::processFileAnalyzeRemoteInfo(
             done = true;
         } else {
             // we need to make a request to the server to know that the original file is deleted on the server
+            if (_discoveryData->_account == nullptr) {
+                Q_EMIT _discoveryData->fatalError(tr("account was deleted. Unable to continue"));
+                return;
+            }
             _pendingAsyncJobs++;
             auto job = new RequestEtagJob(_discoveryData->_account, _discoveryData->_baseUrl, _discoveryData->_remoteFolder + originalPath, this);
             connect(job, &RequestEtagJob::finishedSignal, this, [=]() mutable {
@@ -946,10 +950,15 @@ void ProcessDirectoryJob::processFileAnalyzeLocalInfo(
     if (wasDeletedOnClient.first) {
         finalize(processRename(path), wasDeletedOnClient.second.toUtf8() == base._etag ? ParentNotChanged : NormalQuery);
     } else {
+        if (_discoveryData->_account == nullptr) {
+            Q_EMIT _discoveryData->fatalError(tr("account was deleted. Unable to continue"));
+            return;
+        }
+
         // We must query the server to know if the etag has not changed
         _pendingAsyncJobs++;
         QString serverOriginalPath = _discoveryData->_remoteFolder + _discoveryData->adjustRenamedPath(originalPath, SyncFileItem::Down);
-        auto job = new RequestEtagJob(_discoveryData->_account, _discoveryData->_baseUrl, serverOriginalPath, this);
+        auto job = new RequestEtagJob(_discoveryData->_account.get(), _discoveryData->_baseUrl, serverOriginalPath, this);
         connect(job, &RequestEtagJob::finishedSignal, this,
             [job, recurseQueryServer, path = path, postProcessLocalNew, processRename, base, item, originalPath, this] {
                 if (job->httpStatusCode() == 404 || (job->etag().toUtf8() != base._etag && !item->isDirectory()) || _discoveryData->isRenamed(originalPath)) {
@@ -1303,27 +1312,32 @@ void ProcessDirectoryJob::dbError()
 
 DiscoverySingleDirectoryJob *ProcessDirectoryJob::startAsyncServerQuery()
 {
-    auto serverJob = new DiscoverySingleDirectoryJob(_discoveryData->_account, _discoveryData->_baseUrl,
-        _discoveryData->_remoteFolder + _currentFolder._server, this);
+    if (_discoveryData->_account == nullptr) {
+        Q_EMIT _discoveryData->fatalError(tr("account was deleted. Unable to continue"));
+        return nullptr;
+    }
+
+    auto discoveryJob =
+        new DiscoverySingleDirectoryJob(_discoveryData->_account.get(), _discoveryData->_baseUrl, _discoveryData->_remoteFolder + _currentFolder._server, this);
     if (!_dirItem)
-        serverJob->setIsRootPath(); // query the fingerprint on the root
-    connect(serverJob, &DiscoverySingleDirectoryJob::etag, this, &ProcessDirectoryJob::etag);
+        discoveryJob->setIsRootPath(); // query the fingerprint on the root
+    connect(discoveryJob, &DiscoverySingleDirectoryJob::etag, this, &ProcessDirectoryJob::etag);
     _discoveryData->_currentlyActiveJobs++;
     _pendingAsyncJobs++;
-    connect(serverJob, &DiscoverySingleDirectoryJob::finished, this, [this, serverJob](const auto &results) {
+    connect(discoveryJob, &DiscoverySingleDirectoryJob::finished, this, [this, discoveryJob](const auto &results) {
         _discoveryData->_currentlyActiveJobs--;
         _pendingAsyncJobs--;
         if (results) {
             _serverNormalQueryEntries = *results;
             _serverQueryDone = true;
-            if (!serverJob->_dataFingerprint.isEmpty() && _discoveryData->_dataFingerprint.isEmpty())
-                _discoveryData->_dataFingerprint = serverJob->_dataFingerprint;
+            if (!discoveryJob->_dataFingerprint.isEmpty() && _discoveryData->_dataFingerprint.isEmpty())
+                _discoveryData->_dataFingerprint = discoveryJob->_dataFingerprint;
             if (_localQueryDone)
                 this->process();
         } else {
             auto code = results.error().code;
             qCWarning(lcDisco) << "Server error in directory" << _currentFolder._server << code;
-            if (serverJob->isRootPath()) {
+            if (discoveryJob->isRootPath()) {
                 if (code == 404 && _discoveryData->isSpace()) {
                     Q_EMIT _discoveryData->fatalError(tr("This Space is currently unavailable"));
                     return;
@@ -1350,16 +1364,15 @@ DiscoverySingleDirectoryJob *ProcessDirectoryJob::startAsyncServerQuery()
                     .arg(_currentFolder._server.isEmpty() ? QStringLiteral("/") : _currentFolder._server, results.error().message));
         }
     });
-    connect(serverJob, &DiscoverySingleDirectoryJob::firstDirectoryPermissions, this,
-        [this](const RemotePermissions &perms) { _rootPermissions = perms; });
-    serverJob->start();
-    return serverJob;
+    connect(discoveryJob, &DiscoverySingleDirectoryJob::firstDirectoryPermissions, this, [this](const RemotePermissions &perms) { _rootPermissions = perms; });
+    discoveryJob->start();
+    return discoveryJob;
 }
 
 void ProcessDirectoryJob::startAsyncLocalQuery()
 {
     QString localPath = _discoveryData->_localDir + _currentFolder._local;
-    auto localJob = new DiscoverySingleLocalDirectoryJob(_discoveryData->_account, localPath, _discoveryData->_syncOptions._vfs.data());
+    auto localJob = new DiscoverySingleLocalDirectoryJob(localPath, _discoveryData->_syncOptions._vfs.data());
 
     _discoveryData->_currentlyActiveJobs++;
     _pendingAsyncJobs++;
