@@ -76,11 +76,6 @@ qint64 freeSpaceLimit()
     return value;
 }
 
-OwncloudPropagator::~OwncloudPropagator()
-{
-}
-
-
 int OwncloudPropagator::maximumActiveTransferJob()
 {
     if (!_syncOptions._parallelNetworkJobs) {
@@ -521,9 +516,9 @@ void OwncloudPropagator::start(SyncFileItemSet &&items)
                 // since it would be done before the actual remove (issue #1845)
                 // NOTE: Currently this means that we don't update those etag at all in this sync,
                 //       but it should not be a problem, they will be updated in the next sync.
-                for (auto &dir : directories) {
-                    if (dir.second->item()->instruction() == CSYNC_INSTRUCTION_UPDATE_METADATA) {
-                        dir.second->item()->setInstruction(CSYNC_INSTRUCTION_NONE);
+                for (auto &aDir : directories) {
+                    if (aDir.second->item()->instruction() == CSYNC_INSTRUCTION_UPDATE_METADATA) {
+                        aDir.second->item()->setInstruction(CSYNC_INSTRUCTION_NONE);
                         _anotherSyncNeeded = true;
                     }
                 }
@@ -735,7 +730,7 @@ void OwncloudPropagator::reportProgress(const SyncFileItem &item, qint64 bytes)
     Q_EMIT progress(item, bytes);
 }
 
-AccountPtr OwncloudPropagator::account() const
+Account *OwncloudPropagator::account() const
 {
     return _account;
 }
