@@ -224,7 +224,7 @@ public:
 
     [[deprecated("primaryButtonColor is unsupported and removed as of client 7.0")]]
     virtual QmlButtonColor primaryButtonColor() const;
-    [[deprecated("primaryButtonColor is unsupported and removed as of client 7.0")]]
+    [[deprecated("secondaryButtonColor is unsupported and removed as of client 7.0")]]
     virtual QmlButtonColor secondaryButtonColor() const;
 
     /** @return logo for the setup wizard. */
@@ -360,7 +360,7 @@ public:
      *
      * Defaults: "/"
      */
-    virtual QString quotaBaseFolder() const;
+    [[deprecated("quota folder support has been removed as of client 7.0")]] virtual QString quotaBaseFolder() const;
 
     /**
      * The OAuth client_id, secret pair.
