@@ -21,8 +21,8 @@ namespace TestUtils {
     }
 
     FolderMan *folderMan();
-    FolderDefinition createDummyFolderDefinition(const AccountPtr &account, const QString &path);
-    TestUtilsPrivate::AccountStateRaii createDummyAccount(AbstractCredentials *cred);
+    FolderDefinition createDummyFolderDefinition(Account *account, const QString &path);
+    //   TestUtilsPrivate::AccountStateRaii createDummyAccount();
     bool writeRandomFile(const QString &fname, int size = -1);
 
     /***
